@@ -7,4 +7,9 @@ app_name = "django_secret_sharing_api"
 urlpatterns = [
     path("", api_views.SecretCreateView.as_view(), name="create"),
     path("retrieve/", api_views.SecretRetrieveView.as_view(), name="retrieve"),
+    path(
+        "upload-file-url/",
+        api_views.SecretUploadFileURLView.as_view(),
+        name="upload-file-url",
+    ),
 ]
