@@ -1,4 +1,7 @@
+from email.policy import default
+
 from django.conf import settings
+from django.utils.translation import gettext as _
 from django.utils.translation import gettext_lazy as _
 
 
@@ -15,3 +18,8 @@ EXPIRY_TIME_CHOICES = [
 
 EXPIRY_TIME_CHOICES = get_setting("EXPIRY_TIME_CHOICES", default=EXPIRY_TIME_CHOICES)
 PASSWORD_LENGTH = get_setting("PASSWORD_LENGTH", default=32)
+BACKEND = get_setting(
+    "BACKEND", default="django_secret_sharing.backends.aws.AWSBackend"
+)
+AWS_BUCKET = get_setting("AWS_BUCKET", default="")
+AWS_REGION = get_setting("AWS_REGION", default=None)
